first_tx_seq

Function first_tx_seq 

pub fn first_tx_seq(checkpoint: &Checkpoint) -> u64
The sequence number of the first transaction in checkpoint.

network_total_transactions is the cumulative network-wide tx count after this checkpoint executes, so subtracting the number of transactions the checkpoint contains gives the tx_seq of its first entry.