pub fn checkpoint_input_objects(
checkpoint: &Checkpoint,
) -> Result<BTreeMap<ObjectID, (&Object, ObjectDigest)>>Expand description
First-seen input version of every object that existed before
the checkpoint and was used as an input to some transaction in
it. Mirrors the helper of the same name in
sui-indexer-alt-consistent-store::handlers.
Objects created or unwrapped within the checkpoint are
excluded. Used by the diff-based indexes
(object_by_owner etc.) to
remove the rows that the prior state contributed before
re-inserting the rows that the posterior state contributes.